@@ -395,11 +395,11 @@ setMethod("show", "TSmeta", function(object) {
     cat(" using ", object@conType) 
         if(!is.na(object@DateStamp)) cat(" on ",as.character(object@DateStamp)) 
     cat("\n") 
-    if(!is.na(object@TSlabel))       
+    if(!all(is.na(object@TSlabel)))       
             cat("label:        ", object@TSlabel, "\n") 
-    if(!is.na(object@TSdescription))
+    if(!all(is.na(object@TSdescription)))
             cat("description: ", object@TSdescription, "\n") 
-    if(!is.na(object@TSdoc)) 
+    if(!all(is.na(object@TSdoc)) )
             cat("documentaion: ", object@TSdoc, "\n") 
     invisible(NULL)
     })
